import type { GetDocumentTypeNamesGen } from '@contentlayer/core'
import type * as SourceFiles from '@contentlayer/source-files'
import { defineDocumentType } from '@contentlayer/source-files'

export const addComputedFields = <DefName extends GetDocumentTypeNamesGen = string>({
  documentTypes,
  documentTypeName,
  computedFields,
}: {
  documentTypes: SourceFiles.DocumentType[]
  documentTypeName: DefName
  computedFields: SourceFiles.ComputedFields<DefName>
}): void => {
  const documentType = documentTypes.find((_) => _.def().name === documentTypeName)

  if (!documentType) {
    throw new Error(`Document type "${documentTypeName}" not found`)
  }

  const previousDef = documentType.def()
  documentType.def = defineDocumentType(() => ({ ...previousDef, computedFields })).def
}
